import { IActionFunctions, AxisIdentifier } from './GraphContext';
export interface IProps {
    /**
     * Data for the oval and circles:
     * [x1, x2, y]
     * - x1: The x-coordinate of the left edge of the oval.
     * - x2: The x-coordinate of the right edge of the oval.
     * - y: The y-coordinate of the center of the oval.
     */
    Data: [number, number, number];
    /**
     * Fill color of the oval.
     * @type {string}
     */
    Color: string;
    /**
     * Color of text in oval.
     * @type {string}
     */
    TextColor?: string;
    /**
     * The vertical radius of the oval.
     * @type {number}
     */
    Radius: number;
    /**
     * Stroke color of the oval and circles.
     * @optional
     * @type {string}
     */
    BorderColor?: string;
    /**
     * Stroke thickness of the oval and circles.
     * @optional
     * @type {number}
     */
    BorderThickness?: number;
    /**
     * Optional text to display inside the oval.
     * @optional
     * @type {string}
     */
    Text?: string;
    /**
     * Opacity of the oval and circles.
     * @optional
     * @type {number}
     */
    Opacity?: number;
    /**
     * Axis identifier used for vertical positioning.
     * @optional
     * @type {AxisIdentifier}
     */
    Axis?: AxisIdentifier;
    /**
     * Callback function to handle click events on the oval. Provides action functions to update domains.
     * @optional
     * @type {(actions: IActionFunctions) => void}
     */
    OnClick?: (x: number, y: number, actions: IActionFunctions) => void;
}
declare const Oval: (props: IProps) => JSX.Element | null;
export default Oval;
